package openfuture.masterdata;

import java.util.*;

/**
 * This is a default implementation for a Master Data service.
 *
 * Creation date: (09.09.00 22:00:17)
 * @author: Markus Giebeler
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.<p>
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.<p>
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA<br>
 * http://www.gnu.org/copyleft/lesser.html"
 */
public class DefaultMasterDataService implements IMasterDataService {
  /** Field masterDataCache (Hashtable) is used to cache the master data in the service */
  private static Hashtable masterDataCache;

/**
 * Constructor
 */
public DefaultMasterDataService() {
	super();
	initialize();
}
/**
 * Insert the method's description here.
 * 
 * Creation date: (10.09.00 09:40:31)
 * @param type java.lang.String
 * @param container openfuture.masterdata.IMasterDataContainer
 */
public void addMasterDataContainer(String type, IMasterDataContainer container) {
	getMasterDataCache().put(type, container);
}
/**
 * Passes Master Data of the specified type and a given language to the
 * Master Data Provider.
 *
 * Creation date: (09.09.00 21:57:13)
 * @return java.util.Vector
 * @param type java.lang.String
 * @param language java.lang.String
 */
public IMasterDataContainer getMasterData(String type, String language) {
	IMasterDataContainer container = (IMasterDataContainer) getMasterDataCache().get(type);
	if (container == null) {
		initialize();
		container = (IMasterDataContainer) getMasterDataCache().get(type);
		if (container == null) {
			return null;
			// or throw an Exception ...??!
		}
	}
	return container.getMasterData(language);
}
 /**
  * Return contents of field masterDataCache
  * 
  * @return (Hashtable) contents of field masterDataCache
  */
  public static Hashtable getMasterDataCache() {
	return masterDataCache;
  }  
/**
 * Initialize the Master Data cache<br>
 * Must be subclassed to provide some master data.
 *
 * <p>You might want to create an instance of this class or subclass at start-up
 * of your (server) application and initialize is in order to fetch some data,
 * e.g. from a legacy system or interface.
 * 
 * Creation date: (10.09.00 09:38:20)
 */
public void initialize() {
	setMasterDataCache(new Hashtable());
}
 /**
  * Set contents of field masterDataCache to the given value
  * 
  * @param newValue (Hashtable) new value for field masterDataCache
  */
  public static void setMasterDataCache(Hashtable newValue) {
	masterDataCache = newValue;
  }  
}
