package openfuture.masterdata;

import java.util.*;
import java.io.Serializable;

/**
 * This interface defines the services a Master Data Container must implement.
 * A Master Data Container is responsible to maintain the Master Data in a list
 * and select a (language dependent) subset of them to be passed from the service
 * to the provider.
 * 
 * Creation date: (10.09.00 09:32:25)
 * @author: Markus Giebeler
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.<p>
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.<p>
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA<br>
 * http://www.gnu.org/copyleft/lesser.html"
 */
public interface IMasterDataContainer extends Serializable {
/**
 * return the contained data
 * 
 * Creation date: (10.09.00 10:10:44)
 * @return Vector
 */
public Vector getData();
/**
 * Provides another container with master data for the given language
 * 
 * Creation date: (10.09.00 10:10:44)
 * @return IMasterDataContainer
 * @param language java.lang.String
 */
public IMasterDataContainer getMasterData(String language);
/**
 * indicates if this container can provide data for a given language.
 * 
 * Creation date: (10.09.00 10:10:44)
 * @return boolean
 * @param language java.lang.String
 */
public boolean hasMasterData(String language);
/**
 * Insert the method's description here.
 * 
 * Creation date: (10.09.00 10:10:44)
 * @return boolean
 * @param language java.lang.String
 */
public void setLanguage(String language);
}
