package openfuture.masterdata;

import java.util.*;

/**
 * This class implements the <tt>IMasterDataContainer</tt> interface in order to
 * provide a container for non-language dependent master data.
 * 
 * Creation date: (10.09.00 09:32:50)
 * @author: Markus Giebeler
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.<p>
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.<p>
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA<br>
 * http://www.gnu.org/copyleft/lesser.html"
 */
public class MasterDataContainer implements IMasterDataContainer {
  /** Field data (Vector) is used to hold the data */
  private Vector data;

/**
 * Constructor
 */
public MasterDataContainer() {
	super();
}
/**
 * Constructor
 * 
 * Creation date: (10.09.00 09:34:37)
 * @param data java.util.Vector
 */
public MasterDataContainer(Vector data) {
	setData(data);
}
 /**
  * Return contents of field data
  * 
  * @return (Vector) contents of field data
  */
  public final Vector getData() {
	if(data==null) {
	  data = new Vector(); 
	}
	return data;
  }  
/**
 * Provides another container with master data for the given language
 * As this implementation is used to manage non-language dependent master data,
 * it always returns a new container which contains all master data
 * 
 * Creation date: (10.09.00 10:10:44)
 * @return IMasterDataContainer
 * @param language java.lang.String
 */
public IMasterDataContainer getMasterData(String language) {
	Object[] tData = getData().toArray();
	Arrays.sort(tData);
	Vector v = new Vector();
	for(int i=0; i<tData.length; i++) {
		v.addElement(tData[i]);
	}
	return new MasterDataContainer(v);
}
/**
 * Indicates if this container can provide data for a given language.
 * As this implementation is used to manage non-language dependent master data,
 * it always contains data for the "right" language, whatever the argument is.
 * 
 * Creation date: (10.09.00 10:10:44)
 * @return boolean
 * @param language java.lang.String
 */
public boolean hasMasterData(String language) {
	return true;
}
 /**
  * Set contents of field data to the given value
  * 
  * @param newValue (Vector) new value for field data
  */
  public final void setData(Vector newValue) {
	this.data = newValue;
  }  
 /**
  * Set contents of field language to the given value
  * 
  * @param newValue (String) new value for field language
  */
  public final void setLanguage(String newValue) {
  }  
}
