package openfuture.util.misc;
/*
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.<p>
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.<p>
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA<br>
 * http://www.gnu.org/copyleft/lesser.html
 */

import java.util.Enumeration;
import java.util.Hashtable;
import java.util.Vector;
import openfuture.masterdata.IMasterDataContainer;
import openfuture.masterdata.MasterDataContainer;

// Configuration Management Information: 
// -------------------------------------
// $Id:  $
//
// Version History:
// ----------------
// $Log: $
//
// ***********************************************************************************
/**
 * LocalizedMasterDataContainer.java
 *
 *
 * Created: Wed Jan 10 14:25:03 2001
 *
 * @author <a href="mailto:wolfgang@openfuture.de">Wolfgang Reissenberger</a>
 * @version $Revision: $
 */

public class LocalizedMasterDataContainer implements IMasterDataContainer  {


	private Hashtable dataHash;
	private String defaultLanguage;

	/**
	 * Creates a new <code>LocalizedMasterDataContainer</code> instance.
	 *
	 */
	public LocalizedMasterDataContainer() {
	setDataHash(new Hashtable());
	}
    
	// implementation of openfuture.masterdata.IMasterDataContainer interface

	/**
	 * Returns the  master data for all languages.
	 *
	 * @return the concatenation of the language dependant master 
	 *         data vectors.
	 */
	public Vector getData() {

	Vector allData = new Vector();

	Enumeration enum = getDataHash().keys();

	while(enum.hasMoreElements()) {
	    IMasterDataContainer container = 
		(IMasterDataContainer) enum.nextElement();
	    allData.addAll(container.getData());
	}
	return allData;
	}

	/**
	 * Returns the master data container for the given language key.
	 *
	 * @param language language key
	 * @return master data container
	 */
	public IMasterDataContainer getMasterData(String language) {
	return (IMasterDataContainer) getDataHash().get(language);
	}

	/**
	 * Returns <code>true</code>, iff this container has master data
	 * for the given language key.
	 *
	 * @param language language key
	 * @return (see description)
	 */
	public boolean hasMasterData(String language) {
	return getDataHash().containsKey(language);
	}

	/**
	 * Set the default language.
	 *
	 * @param language language key
	 */
	public void setLanguage(String language) {
	this.defaultLanguage = language;
	}


	public void addMasterData(String language, Vector data) {
	MasterDataContainer container = new MasterDataContainer(data);
	container.setLanguage(language);
	getDataHash().put(language, container);
	}
    
	/**
	 * Get the value of dataHash.
	 * @return value of dataHash.
	 */
	protected Hashtable getDataHash() {
	return dataHash;
	}
    
	/**
	 * Set the value of dataHash.
	 * @param v  Value to assign to dataHash.
	 */
	protected void setDataHash(Hashtable  v) {
	this.dataHash = v;
	}
    
}