package openfuture.util.misc;
/*
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.<p>
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.<p>
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA<br>
 * http://www.gnu.org/copyleft/lesser.html
 */

import java.util.Enumeration;
import java.util.ResourceBundle;
import java.util.Vector;
import openfuture.masterdata.IMasterDataContainer;
import openfuture.masterdata.IMasterDataSource;
import openfuture.masterdata.IMasterDataSource;
import openfuture.masterdata.LDMasterData;
import openfuture.util.misc.LocalizedMasterDataContainer;
import java.util.Locale;

// Configuration Management Information: 
// -------------------------------------
// $Id:  $
//
// Version History:
// ----------------
// $Log: $
//
// ***********************************************************************************
/**
 * Source of master data using resource bundles.<p>
 *
 *
 * Created: Wed Jan 10 10:36:15 2001
 *
 * @author <a href="mailto:wolfgang@openfuture.de">Wolfgang Reissenberger</a>
 * @version $Revision: $
 */

public class RBMasterDataSource  implements IMasterDataSource  {
	

	private String type;
	private LocalizedMasterDataContainer container;
    

	/**
	 * Creates a new <code>RBMasterDataSource</code> instance. For
	 * each given {@link java.util.ResourceBundle ResourceBundle},
	 * a vector of {@link openfuture.masterdata.LDMasterData LDMasterData}
	 * is added, one for each of the given keys. The description is
	 * retreived from the given resource bundle.<p>
	 * <emph>Special case</emph>: If the key is <code>null</code> or
	 * an empty string, the empty string is added as key and as value
	 * for each resource bundle.
	 *
	 * @param type type of master data
	 * @param bundles vector of {@link java.util.ResourceBundle ResourceBundle}
	 *                objects.
	 * @param keys vector of {@link java.lang.String String} objects.
	 */
	public RBMasterDataSource(String type, Vector bundles, 
			      Vector locales, String[] keys) {

	// create the master data container
	setContainer(new LocalizedMasterDataContainer());

	// iterate over all resource bundles
	Enumeration ebundles = bundles.elements();
	Enumeration elocales = locales.elements();

	while (ebundles.hasMoreElements() && elocales.hasMoreElements()) {
	    ResourceBundle bundle = (ResourceBundle) ebundles.nextElement();
	    String lang = ((Locale) elocales.nextElement()).toString();

	    // vector storing the single master data entries
	    Vector data = new Vector();

	    // iterate over all keys
	    for(int i = 0; i < keys.length; i++) {
		String key = keys[i];

		if (key == null || key.equals("")) {
		    data.add(new LDMasterData("", lang, ""));
		} else {
		    String text = bundle.getString(key);

		    if (text != null) {
			data.add(new LDMasterData(key, lang, text));
		    }
		}
	    }
	    // add master data for the actual language
	    getContainer().addMasterData(lang, data);
	}

	}

	/**
	 * If {@link #getType()} returns <code>null</code> or is equal to
	 * <code>type</code>, the container with master data is
	 * returned. Otherwise, <code>null</code> will be returned.
	 *
	 * @param type master data type
	 * @return a master data container.
	 */
	public IMasterDataContainer getMasterData(String type) {

	if (getType() == null) return (getContainer());

	if (type == null || (! type.equals(getType()))) return null;

	return (getContainer());
	}

    
	/**
	 * Get the value of type.
	 * @return value of type.
	 */
	public String getType() {
	return type;
	}
    
	/**
	 * Set the value of type.
	 * @param v  Value to assign to type.
	 */
	protected void setType(String  v) {
	this.type = v;
	}


	/**
	 * Get the value of container.
	 * @return value of container.
	 */
	protected LocalizedMasterDataContainer getContainer() {
	return container;
	}
    
	/**
	 * Set the value of container.
	 * @param v  Value to assign to container.
	 */
	protected void setContainer(LocalizedMasterDataContainer  v) {
	this.container = v;
	}
    
    
   
}